<?php
/**
 * Nav menu walker.
 *
 */

if ( ! defined( 'ABSPATH' ) ) {
	
	exit;
}

//////////////////////////////////////////////////
/**
 * Nav menu walker.
 *
 */
class Bahotel_L_Nav_Menu extends Walker_Nav_Menu {
	
	//////////////////////////////////////////////////
	public static function init() {
		
		// Provide data.
		add_filter( 'bahotel_l_nav_menu_walker', array( __CLASS__, 'get_name' ), 10, 2 );
		add_filter( 'nav_menu_link_attributes', array( __CLASS__, 'get_menu_link_attr' ), 10, 3 );
		add_filter( 'bahotel_l_nav_menu_fallback', array( __CLASS__, 'get_fallback' ), 10, 2 );
	}
	

	
	////////////////////////////////////////////////////////////
	//// Provide data.
	////////////////////////////////////////////////////////////

	//////////////////////////////////////////////////
	/**
	 * Returns this class name.
	 *
	 * @since 1.0.0
	 *
	 * @param misc $content Content to filter.
	 * 
	 * @return string
	 */
	static function get_name( $content = null ) {
		
		return __CLASS__;
	}
	
	
	
	//////////////////////////////////////////////////
	/**
	 * Returns this class name.
	 *
	 * @since 1.0.0
	 *
	 * @param array $atts Menu item attributes.
	 * @param object $item Menu item.
	 * @param array $args Menu item arguments.
	 * 
	 * @return string
	 */
	static function get_menu_link_attr( $atts, $item, $args ) {
	
	$atts['href'] = ! empty( $item->url ) ? $item->url : '';
	
	if ( isset( $atts['data-toggle'] ) ) {
		
		unset( $atts['data-toggle'] );
	} 
	
	return $atts; 
}
	
	
	
	//////////////////////////////////////////////////
	/**
	 * Returns this class fallback function name.
	 *
	 * @since 1.0.0
	 *
	 * @param misc $content Content to filter.
	 * 
	 * @return string
	 */
	static function get_fallback( $content = null ) {
		
		return __CLASS__ . '::fallback';
	}
	
	
	
	////////////////////////////////////////////////////////////
	//// Menu construction.
	////////////////////////////////////////////////////////////
	
	
	/**
	 * @see Walker::start_lvl()
	 * @since 1.0.0
	 *
	 * @param string $output Passed by reference. Used to append additional content.
	 * @param int $depth Depth of page. Used for padding.
	 */
	public function start_lvl( &$output, $depth = 0, $args = array() ) {
		
		$indent = str_repeat( "\t", $depth );
		
		$output .= "\n$indent<ul role=\"menu\" class=\" dropdown-menu\">\n";
	}

	/**
	 * @see Walker::start_el()
	 * @since 1.0.0
	 *
	 * @param string $output Passed by reference. Used to append additional content.
	 * @param object $item Menu item data object.
	 * @param int $depth Depth of menu item. Used for padding.
	 * @param int $current_page Menu item ID.
	 * @param object $args
	 */
	public function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {
		
		$indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';

		/**
		 * Dividers, Headers or Disabled
		 * =============================
		 * Determine whether the item is a Divider, Header, Disabled or regular
		 * menu item. To prevent errors we use the strcasecmp() function to so a
		 * comparison that is not case sensitive. The strcasecmp() function returns
		 * a 0 if the strings are equal.
		 */
		if ( strcasecmp( $item->attr_title, 'divider' ) == 0 && $depth === 1 ) {
			
			$output .= $indent . '<li role="presentation" class="divider">';
			
		} else if ( strcasecmp( $item->title, 'divider') == 0 && $depth === 1 ) {
			
			$output .= $indent . '<li role="presentation" class="divider">';
			
		} else if ( strcasecmp( $item->attr_title, 'dropdown-header') == 0 && $depth === 1 ) {
			
			$output .= $indent . '<li role="presentation" class="dropdown-header">' . esc_html( $item->title );
			
		} else if ( strcasecmp($item->attr_title, 'disabled' ) == 0 ) {
			
			$output .= $indent . '<li role="presentation" class="disabled"><a href="#">' . esc_html( $item->title ) . '</a>';
			
		} else {

			$class_names = $value = '';

			$classes = empty( $item->classes ) ? array() : (array) $item->classes;
			$classes[] = 'menu-item-' . $item->ID;

			$class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item, $args ) );

			if( $args->has_children && $depth === 0 ) {
				
				$class_names .= ' dropdown';
				
			} elseif ( $args->has_children && $depth > 0 ) {
				
				$class_names .= ' dropdown dropdown-submenu';
			}

			if ( in_array( 'current-menu-item', $classes ) ) {
			
				$class_names .= ' active';
			}

			$class_names = $class_names ? ' class="nav-item ' . esc_attr( $class_names ) . '"' : '';

			$id = apply_filters( 'nav_menu_item_id', 'menu-item-'. $item->ID, $item, $args );
			$id = $id ? ' id="' . esc_attr( $id ) . '"' : '';

			$output .= $indent . '<li' . $id . $value . $class_names .'>';

			$atts = array();
			//$atts['title']  = ! empty( $item->title )	? $item->title	: '';
            
			$atts['target'] = ! empty( $item->target )	? $item->target	: '';
			$atts['rel']	= ! empty( $item->xfn )		? $item->xfn	: '';
			$atts['href']   = ! empty( $item->url )		? $item->url	: '';

			// If item has_children add atts to a.

			if ( $args->has_children ) {
				
				$atts['href']   		= '#';
				$atts['data-toggle']	= 'dropdown';
				$atts['class']			= 'dropdown-toggle nav-link';
				$atts['aria-haspopup']	= 'true';
				
			} else {
				
				$atts['href'] = ! empty( $item->url ) ? $item->url : '';
				$atts['class'] = 'nav-link';
			}
			
			if ( $depth > 0 && ! in_array( 'menu-item-has-children', $classes ) ) {
				
				$atts['class'] = 'dropdown-item nav-link';
				
			} elseif ( $depth > 0 && in_array( 'menu-item-has-children', $classes ) ) {
				
				$atts['data-toggle']	= 'dropdown';
				$atts['class']			= 'dropdown-toggle dropdown-item nav-link';
			}

			if ( $depth === 0 ) {
				
				$atts['class'] = 'nav-link';
			}
			
			if ($depth === 0 && in_array('menu-item-has-children', $classes)) {
				
				$atts['class']	   .= ' dropdown-toggle';
				$atts['data-toggle']  = 'dropdown';
			}
			
			if ( in_array('current-menu-item', $item->classes ) ) {
				
				$atts['class'] .= ' active';
			}

			$atts = apply_filters( 'nav_menu_link_attributes', $atts, $item, $args );
			
			$attributes = '';
			foreach ( $atts as $attr => $value ) {
				
				if ( ! empty( $value ) ) {
					
					$value = ( 'href' === $attr ) ? esc_url( $value ) : esc_attr( $value );
					$attributes .= ' ' . $attr . '="' . $value . '"';
				}
			}

            //$attributes .= ' tabindex="0"';

			$item_output = $args->before;

			/*
			 * Glyphicons
			 * ===========
			 * Since the the menu item is NOT a Divider or Header we check the see
			 * if there is a value in the attr_title property. If the attr_title
			 * property is NOT null we apply it as the class name for the glyphicon.
			 */
			if ( ! empty( $item->attr_title ) ) {
				
				$item_output .= '<a'. $attributes .'>';
				
			} else {
				
				$item_output .= '<a'. $attributes .'>';
			}

			$item_output .= $args->link_before . apply_filters( 'the_title', $item->title, $item->ID ). $args->link_after;
			$item_output .= ( $args->has_children ) ? '<span class="caret"><i class="fas fa-chevron-down"></i></span></a>' : '</a>';
			$item_output .= $args->after;

			$output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args );
		}
	}

	/**
	 * @see Walker::start_el()
	 * @since 1.0.0
	 *
	 * @param object $element Data object
	 * @param array $children_elements List of elements to continue traversing.
	 * @param int $max_depth Max depth to traverse.
	 * @param int $depth Depth of current element.
	 * @param array $args
	 * @param string $output Passed by reference. Used to append additional content.
	 * @return null Null on failure with no changes to parameters.
	 */
	public function display_element( $element, &$children_elements, $max_depth, $depth, $args, &$output ) {
		
		if ( ! $element ) {
			
			return;
		}

		$id_field = $this->db_fields['id'];

		// Display this element.
		if ( is_object( $args[0] ) ) {
			
			$args[0]->has_children = ! empty( $children_elements[ $element->$id_field ] );
		}

		parent::display_element( $element, $children_elements, $max_depth, $depth, $args, $output );
	}

	/**
	 * Menu Fallback
	 * =============
	 * If this function is assigned to the wp_nav_menu's fallback_cb variable
	 * and a manu has not been assigned to the theme location in the WordPress
	 * menu manager the function with display nothing to a non-logged in user,
	 * and will add a link to the WordPress menu manager if logged in as an admin.
	 *
	 * @param array $args passed from the wp_nav_menu function.
	 *
	 */
	public static function fallback( $args ) {
		
		extract( $args );

		$fb_output = null;

		if ( $container ) {
			
			$fb_output = '<' . esc_attr($container);

			if ( $container_id ) {
				
				$fb_output .= ' id="' . esc_attr($container_id) . '"';
			}

			if ( $container_class ) {
				
				$fb_output .= ' class="' . esc_attr($container_class) . '"';
			}

			$fb_output .= '>';
		}

		$fb_output .= '<ul';

		if ( $menu_id ) {
			
			$fb_output .= ' id="' . esc_attr($menu_id) . '"';
		}

		if ( $menu_class ) {
			
			$fb_output .= ' class="' . esc_attr($menu_class) . '"';
		}

		$fb_output .= '>';
		$fb_output .= '<li class="nav-item menu-item"><a href="#" class="nav-link">' . esc_html__( 'Home', 'ba-hotel-light' ) . '<div class="menu-top-border"></div></a></li>';
		$fb_output .= '<li class="nav-item menu-item"><a href="#" class="nav-link">' . esc_html__( 'About Us', 'ba-hotel-light' ) . '<div class="menu-top-border"></div></a></li>';
		$fb_output .= '<li class="nav-item menu-item"><a href="#" class="nav-link">' . esc_html__( 'Gallery', 'ba-hotel-light' ) . '<div class="menu-top-border"></div></a></li>';
		$fb_output .= '<li class="nav-item menu-item"><a href="#" class="nav-link">' . esc_html__( 'Contact Us', 'ba-hotel-light' ) . '<div class="menu-top-border"></div></a></li>';
		$fb_output .= '</ul>';

		if ( $container ) {
			
			$fb_output .= '</' . esc_attr($container) . '>';
		}
        
        $fb_output = apply_filters( 'bahotel_l_nav_menu_fallback_html', $fb_output, $args );
        
		echo wp_kses_post($fb_output);
	}
	
	
	////////////////////////////////////////////////////////////
	//// End of our class.
	////////////////////////////////////////////////////////////
}

//////////////////////////////////////////////////
/**
 * Call to setup class.
 */
Bahotel_L_Nav_Menu::init();

